ams.core.param.RParam
=====================

.. currentmodule:: ams.core.param

.. autoclass:: RParam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~RParam.evaluate
       
       
          ~RParam.get_idx
       
       
          ~RParam.parse
       
       
          ~RParam.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~RParam.class_name
      ~RParam.dtype
      ~RParam.n
      ~RParam.shape
      ~RParam.size
      ~RParam.v
   
   